@@ -196,8 +196,8 @@ class GrimoirePage:
         Add command for url
         """
         for e in url:
-            if "http" not in e:
-                e = f"http://{e}"
+            if "http" not in e or "https" not in e:
+                e = f"https://{e}"
             if self.data.get("server") is None:
                 self.data["server"] = {}
             if self.data["server"].get(e) is None:
@@ -216,3 +216,18 @@ class GrimoirePage:
             json.dump(self.data, json_file)
         self.logger.info(f"Removing {url}")
         return True
+
+    def update_data(self) -> bool:
+        """
+        Update all the data
+        """
+        temp = {}
+        for url in self.data["server"]:
+            if "http" not in url:
+                url = f"https://{url}"
+            temp[url] = {"url": url}
+            self.logger.info(f"Adding {url}")
+        self.data["server"] = temp
+        with open(self.setting_manager.data_path, "w") as json_file:
+            json.dump(self.data, json_file)
+        return True
