@@ -1,6 +1,9 @@
-from typing import List
 import logging
+from typing import List, Tuple
+
+from rich.console import Console
 from rich.logging import RichHandler
+from rich.markdown import Markdown
 
 
 class Plugin(object):
@@ -9,7 +12,6 @@ class Plugin(object):
     """
 
     def __init__(self):
-
         FORMAT = "%(message)s"
         logging.basicConfig(
             level="NOTSET",
@@ -39,14 +41,36 @@ class Plugin(object):
         """
         raise NotImplementedError
 
-    def stats(self, directive: str, data: dict) -> List[dict]:
+    def stats(
+        self, directive: str, data: dict
+    ) -> Tuple[List[List], List[List]]:
         """
         Return the stats for the directive
         """
         raise NotImplementedError
 
-    def info(self, directive: str, data: dict):
+    def get_markdown(self):
+        """
+        Return info text as Markdown
+        """
+        raise NotImplementedError
+
+    def info(self):
         """
         Return info of the directive
         """
-        return data.get(directive, dict())
+        console = Console()
+        md = Markdown(self.get_markdown())
+        console.print(md)
+
+    def header_stats(self) -> List[str]:
+        raise NotImplementedError
+
+    def header_error(self) -> List[str]:
+        raise NotImplementedError
+
+    def title_stats(self) -> str:
+        raise NotImplementedError
+
+    def title_error(self) -> str:
+        raise NotImplementedError
